
#ifndef IMAGECONTAINER_H
#define IMAGECONTAINER_H

#include <iostream>
#include <random>
#include <vector>

#include "GacenException.h"

namespace gacen {
    /*! \brief Manage data
     *
     *  class to manage data
     * 
     */
    class DataContainer
    {
    public:
    
        // Constructors/Destructors
        //  
    
    
        /*! \brief Constructor
         *
         *  Empty Constructor
         */
        DataContainer ();
    
        /*! \brief Constructor with initialization
         *
         *  Initialize the data to n zero images
         */
        DataContainer (int ndet, int size);
    
        /*! \brief Destructor
         *
         *  Delete allocated memory:
         *  - ImgList
         */
        virtual ~DataContainer ();
    
        /*
         * Accessor
         */

        /*! \brief Set the data
         *
         * For now, just generate random value
         *
         */
        void set_data ();

        /*! \brief Get the image size
         *
         * \return image size
         *
         */
        int get_img_size();

        /*! \brief Get the number of image
         *
         * \return number of image
         *
         */
        int get_nb_img();

        /*! \brief Get the value of one pixel
         *
         * \return pixel value
         *
         */
        float get_pix_val(int n, int i, int j);

        /*
         * Other methods
         */
    
    protected:
    
    private:
        /*
         * Dummy image
         */

        /*! \brief Image size
         *
         * Image was assume to be square: size_x = size_y = img_size
         *
         */
        int img_size;

        /*! Number of images */
        int nb_img;

        /*! \brief List of the images
         *
         * Each image is a 2D array of size img_size x img_size
         *
         */
        std::vector <float**> ImgList;

        /*
         * Private method
         */

        /*! \brief Get a random float
         *
         * \param mu mean value
         * \param sigma standart deviation
         *
         * \return a random float using std::normal_distribution
         *
         */
        float get_rand_gauss(float mu, float sigma);

        /*! \brief Set the number of image
         *
         *  \param value number of image
         *
         */
        void set_nb_img(int value);

        /*! \brief Set the image size
         *
         * Image was assume to be square: size_x = size_y = img_size
         *
         * \param value image size
         *
         */
        void set_img_size(int value);

    };
}
#endif // IMAGECONTAINER_H
